@@ -472,6 +472,7 @@ class AppSyncTransformer(
         enable_dynamo_point_in_time_recovery: typing.Optional[builtins.bool] = None,
         field_log_level: typing.Optional[aws_cdk.aws_appsync.FieldLogLevel] = None,
         nested_stack_name: typing.Optional[builtins.str] = None,
+        output_path: typing.Optional[builtins.str] = None,
         post_cdk_transformers: typing.Optional[typing.Sequence[typing.Any]] = None,
         pre_cdk_transformers: typing.Optional[typing.Sequence[typing.Any]] = None,
         sync_enabled: typing.Optional[builtins.bool] = None,
@@ -489,6 +490,7 @@ class AppSyncTransformer(
         :param enable_dynamo_point_in_time_recovery: (experimental) Whether to enable dynamo Point In Time Recovery. Default to false for backwards compatibility Default: false
         :param field_log_level: (experimental) Optional. {@link FieldLogLevel} type for AppSync GraphqlApi log level Default: FieldLogLevel.NONE
         :param nested_stack_name: (experimental) Specify a custom nested stack name. Default: "appsync-nested-stack"
+        :param output_path: (experimental) Path where generated resolvers are output. Default: "./appsync"
         :param post_cdk_transformers: (experimental) Optional. Additonal custom transformers to run after the CDK resource generations. Mostly useful for deep level customization of the generated CDK CloudFormation resources. These should extend Transformer class from graphql-transformer-core Default: undefined
         :param pre_cdk_transformers: (experimental) Optional. Additonal custom transformers to run prior to the CDK resource generations. Particularly useful for custom directives. These should extend Transformer class from graphql-transformer-core Default: undefined
         :param sync_enabled: (experimental) Whether to enable Amplify DataStore and Sync Tables. Default: false
@@ -506,6 +508,7 @@ class AppSyncTransformer(
             enable_dynamo_point_in_time_recovery=enable_dynamo_point_in_time_recovery,
             field_log_level=field_log_level,
             nested_stack_name=nested_stack_name,
+            output_path=output_path,
             post_cdk_transformers=post_cdk_transformers,
             pre_cdk_transformers=pre_cdk_transformers,
             sync_enabled=sync_enabled,
@@ -711,6 +714,7 @@ class AppSyncTransformer(
         "enable_dynamo_point_in_time_recovery": "enableDynamoPointInTimeRecovery",
         "field_log_level": "fieldLogLevel",
         "nested_stack_name": "nestedStackName",
+        "output_path": "outputPath",
         "post_cdk_transformers": "postCdkTransformers",
         "pre_cdk_transformers": "preCdkTransformers",
         "sync_enabled": "syncEnabled",
@@ -730,6 +734,7 @@ class AppSyncTransformerProps:
         enable_dynamo_point_in_time_recovery: typing.Optional[builtins.bool] = None,
         field_log_level: typing.Optional[aws_cdk.aws_appsync.FieldLogLevel] = None,
         nested_stack_name: typing.Optional[builtins.str] = None,
+        output_path: typing.Optional[builtins.str] = None,
         post_cdk_transformers: typing.Optional[typing.Sequence[typing.Any]] = None,
         pre_cdk_transformers: typing.Optional[typing.Sequence[typing.Any]] = None,
         sync_enabled: typing.Optional[builtins.bool] = None,
@@ -745,6 +750,7 @@ class AppSyncTransformerProps:
         :param enable_dynamo_point_in_time_recovery: (experimental) Whether to enable dynamo Point In Time Recovery. Default to false for backwards compatibility Default: false
         :param field_log_level: (experimental) Optional. {@link FieldLogLevel} type for AppSync GraphqlApi log level Default: FieldLogLevel.NONE
         :param nested_stack_name: (experimental) Specify a custom nested stack name. Default: "appsync-nested-stack"
+        :param output_path: (experimental) Path where generated resolvers are output. Default: "./appsync"
         :param post_cdk_transformers: (experimental) Optional. Additonal custom transformers to run after the CDK resource generations. Mostly useful for deep level customization of the generated CDK CloudFormation resources. These should extend Transformer class from graphql-transformer-core Default: undefined
         :param pre_cdk_transformers: (experimental) Optional. Additonal custom transformers to run prior to the CDK resource generations. Particularly useful for custom directives. These should extend Transformer class from graphql-transformer-core Default: undefined
         :param sync_enabled: (experimental) Whether to enable Amplify DataStore and Sync Tables. Default: false
@@ -772,6 +778,8 @@ class AppSyncTransformerProps:
             self._values["field_log_level"] = field_log_level
         if nested_stack_name is not None:
             self._values["nested_stack_name"] = nested_stack_name
+        if output_path is not None:
+            self._values["output_path"] = output_path
         if post_cdk_transformers is not None:
             self._values["post_cdk_transformers"] = post_cdk_transformers
         if pre_cdk_transformers is not None:
@@ -878,6 +886,17 @@ class AppSyncTransformerProps:
         result = self._values.get("nested_stack_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def output_path(self) -> typing.Optional[builtins.str]:
+        '''(experimental) Path where generated resolvers are output.
+
+        :default: "./appsync"
+
+        :stability: experimental
+        '''
+        result = self._values.get("output_path")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def post_cdk_transformers(self) -> typing.Optional[typing.List[typing.Any]]:
         '''(experimental) Optional.
